==> ejc-middlemeasurement-impl-3.0.0-20221118.082653-234-sources.jar: com/ejianc/business/middlemeasurement/bean/EngineermeasurementEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.EngineermeasurementdetailEntity;
/**
 * 工程计量台账
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_engineermeasurement")
public class EngineermeasurementEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="reporting_time")
    private java.util.Date reportingTime; // 报量时间
    @TableField(value="bill_code")
    private java.lang.String billCode; // 编号
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="actual_completed_this_period")
    private java.math.BigDecimal actualCompletedThisPeriod; // 本期实际完成量
    @TableField(value="contract_amount")
    private java.math.BigDecimal contractAmount; // 合同金额
    @TableField(value="cumulative_completed")
    private java.math.BigDecimal cumulativeCompleted; // 累计实际完成量
    @TableField(value="cumulative_completed_proportion")
    private java.math.BigDecimal cumulativeCompletedProportion; // 累计实际完成比例
    @TableField(value="current_batch")
    private java.math.BigDecimal currentBatch; // 本期批量
    @TableField(value="cumulative_batch")
    private java.math.BigDecimal cumulativeBatch; // 累计批量
    @TableField(value="current_collection")
    private java.math.BigDecimal currentCollection; // 本期收款金额
    @TableField(value="cumulative_collection")
    private java.math.BigDecimal cumulativeCollection; // 累计收款金额
    @TableField(value = "original_id")
    private java.lang.Long originalId;
    @TableField(value = "accumulated_contractual_receivables")
    private java.math.BigDecimal accumulatedContractualReceivables;
    @TableField(exist=false)
    @SubEntity(serviceName="engineermeasurementdetailService", pidName = "mid")
    private List<EngineermeasurementdetailEntity> engineermeasurementdetailEntities = new ArrayList<>(); // 工程计量台账子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 报量时间
     */
    public java.util.Date getReportingTime() {
        return reportingTime;
    }

    /**
     * 报量时间
     */
    public void setReportingTime(java.util.Date reportingTime) {
        this.reportingTime = reportingTime;
    }
    /**
     * 编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 本期实际完成量
     */
    public java.math.BigDecimal getActualCompletedThisPeriod() {
        return actualCompletedThisPeriod;
    }

    /**
     * 本期实际完成量
     */
    public void setActualCompletedThisPeriod(java.math.BigDecimal actualCompletedThisPeriod) {
        this.actualCompletedThisPeriod = actualCompletedThisPeriod;
    }
    /**
     * 合同金额
     */
    public java.math.BigDecimal getContractAmount() {
        return contractAmount;
    }

    /**
     * 合同金额
     */
    public void setContractAmount(java.math.BigDecimal contractAmount) {
        this.contractAmount = contractAmount;
    }
    /**
     * 累计实际完成量
     */
    public java.math.BigDecimal getCumulativeCompleted() {
        return cumulativeCompleted;
    }

    /**
     * 累计实际完成量
     */
    public void setCumulativeCompleted(java.math.BigDecimal cumulativeCompleted) {
        this.cumulativeCompleted = cumulativeCompleted;
    }
    /**
     * 累计实际完成比例
     */
    public java.math.BigDecimal getCumulativeCompletedProportion() {
        return cumulativeCompletedProportion;
    }

    /**
     * 累计实际完成比例
     */
    public void setCumulativeCompletedProportion(java.math.BigDecimal cumulativeCompletedProportion) {
        this.cumulativeCompletedProportion = cumulativeCompletedProportion;
    }
    /**
     * 本期批量
     */
    public java.math.BigDecimal getCurrentBatch() {
        return currentBatch;
    }

    /**
     * 本期批量
     */
    public void setCurrentBatch(java.math.BigDecimal currentBatch) {
        this.currentBatch = currentBatch;
    }
    /**
     * 累计批量
     */
    public java.math.BigDecimal getCumulativeBatch() {
        return cumulativeBatch;
    }

    /**
     * 累计批量
     */
    public void setCumulativeBatch(java.math.BigDecimal cumulativeBatch) {
        this.cumulativeBatch = cumulativeBatch;
    }
    /**
     * 本期收款金额
     */
    public java.math.BigDecimal getCurrentCollection() {
        return currentCollection;
    }

    /**
     * 本期收款金额
     */
    public void setCurrentCollection(java.math.BigDecimal currentCollection) {
        this.currentCollection = currentCollection;
    }
    /**
     * 累计收款金额
     */
    public java.math.BigDecimal getCumulativeCollection() {
        return cumulativeCollection;
    }

    /**
     * 累计收款金额
     */
    public void setCumulativeCollection(java.math.BigDecimal cumulativeCollection) {
        this.cumulativeCollection = cumulativeCollection;
    }
    
    /**
     * 工程计量台账子表
     */
    public List<EngineermeasurementdetailEntity> getEngineermeasurementdetailEntities() {
        return engineermeasurementdetailEntities;
    }

    /**
     * 工程计量台账子表
     */
    public void setEngineermeasurementdetailEntities(List<EngineermeasurementdetailEntity> engineermeasurementdetailEntities) {
        this.engineermeasurementdetailEntities = engineermeasurementdetailEntities;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    public BigDecimal getAccumulatedContractualReceivables() {
        return accumulatedContractualReceivables;
    }

    public void setAccumulatedContractualReceivables(BigDecimal accumulatedContractualReceivables) {
        this.accumulatedContractualReceivables = accumulatedContractualReceivables;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/bean/EngineermeasurementEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.EngineermeasurementdetailEntity;
/**
 * 工程计量台账
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_engineermeasurement")
public class EngineermeasurementEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="reporting_time")
    private java.util.Date reportingTime; // 报量时间
    @TableField(value="bill_code")
    private java.lang.String billCode; // 编号
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="actual_completed_this_period")
    private java.math.BigDecimal actualCompletedThisPeriod; // 本期实际完成量
    @TableField(value="contract_amount")
    private java.math.BigDecimal contractAmount; // 合同金额
    @TableField(value="cumulative_completed")
    private java.math.BigDecimal cumulativeCompleted; // 累计实际完成量
    @TableField(value="cumulative_completed_proportion")
    private java.math.BigDecimal cumulativeCompletedProportion; // 累计实际完成比例
    @TableField(value="current_batch")
    private java.math.BigDecimal currentBatch; // 本期批量
    @TableField(value="cumulative_batch")
    private java.math.BigDecimal cumulativeBatch; // 累计批量
    @TableField(value="current_collection")
    private java.math.BigDecimal currentCollection; // 本期收款金额
    @TableField(value="cumulative_collection")
    private java.math.BigDecimal cumulativeCollection; // 累计收款金额
    @TableField(value = "original_id")
    private java.lang.Long originalId;
    @TableField(value = "accumulated_contractual_receivables")
    private java.math.BigDecimal accumulatedContractualReceivables;//累计合同约定应收金额
    @TableField(value = "current_receivables")
    private java.math.BigDecimal currentReceivables;//合同约定本期应收金额
    @TableField(exist=false)
    @SubEntity(serviceName="engineermeasurementdetailService", pidName = "mid")
    private List<EngineermeasurementdetailEntity> engineermeasurementdetailEntities = new ArrayList<>(); // 工程计量台账子表
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 报量时间
     */
    public java.util.Date getReportingTime() {
        return reportingTime;
    }

    /**
     * 报量时间
     */
    public void setReportingTime(java.util.Date reportingTime) {
        this.reportingTime = reportingTime;
    }
    /**
     * 编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 本期实际完成量
     */
    public java.math.BigDecimal getActualCompletedThisPeriod() {
        return actualCompletedThisPeriod;
    }

    /**
     * 本期实际完成量
     */
    public void setActualCompletedThisPeriod(java.math.BigDecimal actualCompletedThisPeriod) {
        this.actualCompletedThisPeriod = actualCompletedThisPeriod;
    }
    /**
     * 合同金额
     */
    public java.math.BigDecimal getContractAmount() {
        return contractAmount;
    }

    /**
     * 合同金额
     */
    public void setContractAmount(java.math.BigDecimal contractAmount) {
        this.contractAmount = contractAmount;
    }
    /**
     * 累计实际完成量
     */
    public java.math.BigDecimal getCumulativeCompleted() {
        return cumulativeCompleted;
    }

    /**
     * 累计实际完成量
     */
    public void setCumulativeCompleted(java.math.BigDecimal cumulativeCompleted) {
        this.cumulativeCompleted = cumulativeCompleted;
    }
    /**
     * 累计实际完成比例
     */
    public java.math.BigDecimal getCumulativeCompletedProportion() {
        return cumulativeCompletedProportion;
    }

    /**
     * 累计实际完成比例
     */
    public void setCumulativeCompletedProportion(java.math.BigDecimal cumulativeCompletedProportion) {
        this.cumulativeCompletedProportion = cumulativeCompletedProportion;
    }
    /**
     * 本期批量
     */
    public java.math.BigDecimal getCurrentBatch() {
        return currentBatch;
    }

    /**
     * 本期批量
     */
    public void setCurrentBatch(java.math.BigDecimal currentBatch) {
        this.currentBatch = currentBatch;
    }
    /**
     * 累计批量
     */
    public java.math.BigDecimal getCumulativeBatch() {
        return cumulativeBatch;
    }

    /**
     * 累计批量
     */
    public void setCumulativeBatch(java.math.BigDecimal cumulativeBatch) {
        this.cumulativeBatch = cumulativeBatch;
    }
    /**
     * 本期收款金额
     */
    public java.math.BigDecimal getCurrentCollection() {
        return currentCollection;
    }

    /**
     * 本期收款金额
     */
    public void setCurrentCollection(java.math.BigDecimal currentCollection) {
        this.currentCollection = currentCollection;
    }
    /**
     * 累计收款金额
     */
    public java.math.BigDecimal getCumulativeCollection() {
        return cumulativeCollection;
    }

    /**
     * 累计收款金额
     */
    public void setCumulativeCollection(java.math.BigDecimal cumulativeCollection) {
        this.cumulativeCollection = cumulativeCollection;
    }
    
    /**
     * 工程计量台账子表
     */
    public List<EngineermeasurementdetailEntity> getEngineermeasurementdetailEntities() {
        return engineermeasurementdetailEntities;
    }

    /**
     * 工程计量台账子表
     */
    public void setEngineermeasurementdetailEntities(List<EngineermeasurementdetailEntity> engineermeasurementdetailEntities) {
        this.engineermeasurementdetailEntities = engineermeasurementdetailEntities;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    public BigDecimal getAccumulatedContractualReceivables() {
        return accumulatedContractualReceivables;
    }

    public void setAccumulatedContractualReceivables(BigDecimal accumulatedContractualReceivables) {
        this.accumulatedContractualReceivables = accumulatedContractualReceivables;
    }

    public BigDecimal getCurrentReceivables() {
        return currentReceivables;
    }

    public void setCurrentReceivables(BigDecimal currentReceivables) {
        this.currentReceivables = currentReceivables;
    }
}
